@@ -1,5 +1,4 @@
-from typing import List, Tuple
-from collections import OrderedDict
+from typing import List, Tuple, OrderedDict
 from pymoo.model.problem import Problem
 from pymoo.algorithms.nsga2 import NSGA2
 from pymoo.factory import (
